from .wav2vec2._wav2vec2_fairseq_dataloader import Wav2Vec2FDataLoader
from .wav2vec2._wav2vec2_ts_dataloader import Wav2Vec2TsDataLoader

__all__ = ["Wav2Vec2FDataLoader", "Wav2Vec2TsDataLoader"]
